import services from '@/services';
import { useRequest } from '@umijs/max';
import { useMemo } from 'react';
import CustomCard from '../../components/CustomCard';
import DisposeFlow from './DisposeFlow';
import styles from './index.less';
import IndustryWiget from './IndustryWiget';
import StatusWiget from './StatusWiget';
const IndustryWarn = ({
  warnLevel,
  setWarnLevel,
}: {
  warnLevel: number;
  setWarnLevel: (val: number) => void;
}) => {
  //环卫固废
  const { data: hwgf } = useRequest(services.CityRiskApi.catalogData, {
    defaultParams: [
      {
        typeCode: 'aq-hwgf',
        id: '1864283207541977090',
      },
    ],
  });

  //道路桥梁
  const dlql = useMemo(() => {
    // return data?.find((item: any) => item?.typeCode === 'dlql');
    return {
      typeCode: 'dlql',
      typeName: '道路桥梁',
      parentCode: null,
      total: '50',
      children: [
        {
          typeCode: 'dl',
          typeName: '道路',
          parentCode: 'dlql',
          total: '0',
          c: '20',
          children: [],
        },
        {
          typeCode: 'ql',
          typeName: '桥梁',
          parentCode: 'dlql',
          total: '50',
          children: [],
        },
      ],
    };
  }, []);
  //城市环卫
  const hw = useMemo(() => {
    // return data?.find((item: any) => item?.typeCode === 'hw');
    return {
      typeCode: 'hw',
      typeName: '环卫',
      parentCode: null,
      total: hwgf?.data?.records?.[0]?.fxys ?? '--',
      children: [
        {
          typeCode: 'dl',
          typeName: '垃圾转运站',
          parentCode: 'dlql',
          total: hwgf?.data?.records?.[0]?.hwss ?? '--',
        },
        {
          typeCode: 'dl',
          typeName: '环卫公厕',
          parentCode: 'dlql',
          total: hwgf?.data?.records?.[0]?.hwgc ?? '--',
        },
        {
          typeCode: 'dl',
          typeName: '环卫车辆',
          parentCode: 'dlql',
          total: hwgf?.data?.records?.[0]?.hwcl ?? '--',
        },
      ],
    };
  }, [hwgf]);
  //固废
  const gf = useMemo(() => {
    // return data?.find((item: any) => item?.typeCode === 'gf');
    return {
      typeCode: 'gf',
      typeName: '固废',
      parentCode: null,
      total: '--',
      children: [
        {
          typeCode: 'dl',
          typeName: '填埋场',
          parentCode: 'dlql',
          total: '--',
        },
        {
          typeCode: 'dl',
          typeName: '焚烧发电厂',
          parentCode: 'dlql',
          total: '--',
        },
        {
          typeCode: 'dl',
          typeName: '餐厨厂',
          parentCode: 'dlql',
          total: '--',
        },
      ],
    };
  }, []);

  return (
    <div className={styles.container}>
      <CustomCard
        title="道路桥梁"
        width={353}
        height={380}
        style={{
          paddingTop: 16,
          paddingRight: 18,
          backgroundColor: 'rgba(63, 149, 229, 0.1)',
        }}
        extra={<StatusWiget status={'红色风险'} />}
      >
        <div className={styles.content}>
          <div className={styles.warp}>
            {dlql?.children?.map((item: any) => {
              return (
                <IndustryWiget
                  data={{
                    ...item,
                    icon: require('@/assets/images/SecurityServiceOverview/qiaoliang.png'),
                    typeCode: dlql?.typeCode,
                    parentData: dlql,
                    warn: 33,
                  }}
                  // style={{ width: 170 }}
                />
              );
            })}
          </div>
          <div className={styles.flow}>
            <DisposeFlow typeCode={dlql?.typeCode} />
          </div>
        </div>
      </CustomCard>
      <CustomCard
        title="环卫作业"
        width={353}
        height={380}
        style={{
          paddingTop: 16,
          paddingRight: 18,
          backgroundColor: 'rgba(63, 149, 229, 0.1)',
        }}
        extra={<StatusWiget status={'橙色风险'} />}
      >
        <div className={styles.content}>
          <div className={styles.warp}>
            {hw?.children?.map((item: any) => {
              return (
                <IndustryWiget
                  data={{
                    ...item,
                    icon: require('@/assets/images/SecurityServiceOverview/huweiIcon.png'),
                    typeCode: hw?.typeCode,
                    parentData: hw,
                  }}
                  style={{ width: 100 }}
                />
              );
            })}
          </div>
          <div className={styles.flow}>
            <DisposeFlow typeCode={hw?.typeCode} />
          </div>
        </div>
      </CustomCard>
      <CustomCard
        title="固废处置"
        width={353}
        height={380}
        style={{
          paddingTop: 16,
          paddingRight: 18,
          backgroundColor: 'rgba(63, 149, 229, 0.1)',
        }}
        extra={<StatusWiget status={'黄色风险'} />}
      >
        <div className={styles.content}>
          <div className={styles.warp}>
            {gf?.children?.map((item: any) => {
              return (
                <IndustryWiget
                  data={{
                    ...item,
                    icon: require('@/assets/images/SecurityServiceOverview/feigu.png'),
                    typeCode: gf?.typeCode,
                    parentData: gf,
                  }}
                  style={{ width: 100 }}
                />
              );
            })}
          </div>
          <div className={styles.flow}>
            <DisposeFlow typeCode={gf?.typeCode} />
          </div>
        </div>
      </CustomCard>
    </div>
  );
};
export default IndustryWarn;
