import CommonTable from '@/components/CommonTable';
import Modal from '@/components/HncyModal';
import Tabs from '@/components/Tabs';
import BaseCard from '@/pages/Common/components/BaseCard';
import services from '@/services';
import { SearchOutlined } from '@ant-design/icons';
import { useModel } from '@umijs/max';
import { useDebounceFn, useRequest } from 'ahooks';
import { Flex, Input } from 'antd';
import { useState } from 'react';
import { colorConfig } from '../../SecurityState/RightLayout/RiskNotice';
import BaseInfo from '../BaseInfo';
import styles from './index.less';
/**
 *
 * @description 行业体征部分
 */

const IndustrySign = ({ param }: { param: any }) => {
  const { initialState } = useModel('@@initialState');
  const { areaId } = initialState;
  const indexIdMap: Record<string, string> = {
    dlql: '202', //道桥
    gf: '209', //固废
    ggzp: '205', //广告牌
    gl: '208', //管廊
    hw: '204', //环卫
    yyrq: '208', //油烟
    zm: '203', //照明
  };
  const [searchData, setSearchData] = useState({
    page: 1,
    count: 10,
  });

  //事件列表
  const [listData, setListData] = useState<any>({
    items: [],
    loading: true,
    total: 0,
    page: 1,
    hasNext: false,
  });
  // 事件详情弹窗
  const [detailModalOpt, setDetailModalOpt] = useState<{
    open: boolean;
    title: string;
    eventId: string;
  }>({
    open: false,
    title: '',
    eventId: '',
  });
  const [fetchParams, setFetchParams] = useState<any>({
    page: 1,
    count: 10,
    parentTypeCode: param?.typeCode,
  });
  const { data: signData } = useRequest(() => {
    return services.Physicalsign.getComparisonIndexInstance({
      indexId: indexIdMap[param?.typeCode],
      physicalSignType: 1,
      indexType: 1,
      objectId: areaId,
    });
  });
  const { data: eventData } = useRequest(
    () => services.CityRiskApi.getEventPage(fetchParams),
    {
      refreshDeps: [fetchParams],
      onSuccess: (res) => {
        console.log(res);

        setListData({
          ...res?.data,
          items: [
            ...listData.items,
            ...res?.data?.items?.map((item: any) => ({
              ...item,
              standardEventTitle: item?.eventType,
              caseStatusText: item?.currentStatus,
              reportTime: item?.warningTime,
              collectionModeName: item?.sourceType,
            })),
          ],
        });
      },
    },
  );
  /** 标题渲染 */
  const titleRender = () => {
    return (
      <Flex align="center" className={styles.modalTitle}>
        <div className={styles.title}>{detailModalOpt?.eventType}</div>
        <span
          className={styles.tag}
          style={{
            backgroundImage: `url(${
              colorConfig[detailModalOpt?.riskLevelName]?.bg
            })`,
            color: colorConfig[detailModalOpt?.riskLevelName]?.color,
          }}
        >
          {detailModalOpt?.riskLevelName}
        </span>
        <span className={styles.type}>{detailModalOpt?.position}</span>
      </Flex>
    );
  };
  const dataSource = [
    {
      key: '1',
      name: '金丰高架桥1号',
      type: '高架桥',
      status: '正常',
      unit: '道桥监管中心',
      address: '成都市成华区双林路256号',
    },
    {
      key: '2',
      name: '金丰高架桥2号',
      type: '高架桥',
      status: '正常',
      unit: '道桥监管中心',
      address: '成都市成华区双林路2156号',
    },
    {
      key: '3',
      name: '金丰高架桥3号',
      type: '高架桥',
      status: '正常',
      unit: '道桥监管中心',
      address: '成都市成华区双林路2156号',
    },
    {
      key: '4',
      name: '金丰高架桥4号',
      type: '高架桥',
      status: '正常',
      unit: '道桥监管中心',
      address: '成都市成华区双林路2156号',
    },
    {
      key: '5',
      name: '金丰高架桥5号',
      type: '高架桥',
      status: '正常',
      unit: '道桥监管中心',
      address: '成都市成华区双林路2156号',
    },
    {
      key: '6',
      name: '金丰高架桥6号',
      type: '高架桥',
      status: '正常',
      unit: '道桥监管中心',
      address: '成都市成华区双林路2156号',
    },
    {
      key: '7',
      name: '金丰高架桥7号',
      type: '高架桥',
      status: '预警',
      unit: '道桥监管中心',
      address: '成都市成华区双林路2156号',
    },
    {
      key: '8',
      name: '金丰高架桥8号',
      type: '高架桥',
      status: '正常',
      unit: '道桥监管中心',
      address: '成都市成华区双林路2156号',
    },
    {
      key: '9',
      name: '金丰高架桥9号',
      type: '高架桥',
      status: '正常',
      unit: '道桥监管中心',
      address: '成都市成华区双林路2156号',
    },
    {
      key: '10',
      name: '金丰高架桥10号',
      type: '高架桥',
      status: '正常',
      unit: '道桥监管中心',
      address: '成都市成华区双林路2156号',
    },
    {
      key: '11',
      name: '金丰高架桥11号',
      type: '高架桥',
      status: '预警',
      unit: '道桥监管中心',
      address: '成都市成华区双林路2156号',
    },
  ];

  const columns = [
    {
      title: '序号',
      dataIndex: 'name',
      key: 'name',
      width: 80,
      ellipsis: true,
      render: (text, record, index) => {
        // 当前页码减1，乘以每页数量，再加上当前行的索引加1
        return `${(searchData?.page - 1) * dataSource?.length + (index + 1)}`;
      },
    },
    {
      width: 180,
      ellipsis: true,
      title: '桥梁名称',
      dataIndex: 'name',
      key: 'name',
    },
    {
      width: 150,
      ellipsis: true,
      title: '桥梁类型',
      dataIndex: 'type',
      key: 'age',
    },
    {
      title: '状态',
      dataIndex: 'status',
      key: 'status',
      width: 80,
      render: (val:string) => {
        return <span style={{color:val=='预警'?'#e66a6e':'#27f77e'}}>{val}</span>
      },
    },
    {
      title: '管理单位',
      dataIndex: 'unit',
      key: 'unit',
      width: 200,
      ellipsis: true,
    },
    {
      title: '位置',
      dataIndex: 'address',
      key: 'address',
      width: 300,
      ellipsis: true,
    },
  ];
  const { run: InputChange } = useDebounceFn(
    (e) => {
      console.log(e.target.value);
    },
    {
      wait: 500,
    },
  );
  return (
    <Flex gap={28} className={styles.wrap}>
      <Flex vertical gap={15} className={styles.left}>
        {/* <BaseCard
          
          title={param?.title+"指数"}
          height={304}
          extra={
            <span
              className={styles.signNum}
              style={{
                color: getCqiStatusStyle(
                  Number(signData?.data?.currentIndex?.cqi),
                )?.color,
              }}
            >
              {signData?.data?.currentIndex?.cqi}
            </span>
          }
          style={{
            paddingTop: 20,
          }}
        >
          <div style={{ marginTop: 20, padding: '0 20px' }}>
            <LineCharts
              lineColor={
                getCqiStatusStyle(Number(signData?.data?.currentIndex?.cqi))
                  ?.color
              }
              colorStops={[
                {
                  offset: 0,
                  color: 'rgba(240, 248, 255, 0.064)', // 0% 处的颜色
                },
                {
                  offset: 1,
                  color: getCqiStatusStyle(
                    Number(signData?.data?.currentIndex?.cqi),
                  )?.background, // 100% 处的颜色
                },
              ]}
              data={
                signData?.data?.currentIndex?.indexDataList?.map(
                  (item: any) => ({
                    name: item.time,
                    value: item.qualitySign,
                  }),
                ) || []
              }
              style={{
                width: 410,
                height: 160,
              }}
            />
          </div>
        </BaseCard> */}
        <BaseCard
          title={param?.title + '概况'}
          height={300}
          style={{
            paddingTop: 20,
          }}
        >
          <div className={styles.list}>
            {param?.parentData?.children?.map((item, index) => (
              <Flex
                className={styles.listItem}
                justify="space-between"
                align="center"
                key={index}
              >
                <span className={styles.name}>{item?.typeName}</span>
                <span>
                  <span className={styles.num}>{item.total}</span>
                  <span>个</span>
                </span>
              </Flex>
            ))}
          </div>
        </BaseCard>
        <BaseCard
          title={param?.title + '类型'}
          height={394}
          style={{
            paddingTop: 20,
          }}
        >
          <div className={styles.list}>
            {param?.parentData?.children?.map((item, index) => (
              <Flex
                className={styles.listItem}
                justify="space-between"
                align="center"
                key={index}
              >
                <span className={styles.name}>{item?.typeName}</span>
                <span>
                  <span className={styles.num}>{item.total}</span>
                  <span>个</span>
                </span>
              </Flex>
            ))}
          </div>
        </BaseCard>
      </Flex>
      <div className={styles.right}>
        <div className={styles.searchWarp}>
          <Tabs
            size="large"
            defaultActiveKey="1"
            centered
            items={[
              { key: '1', label: '全部' },
              { key: '2', label: '异常' },
              { key: '3', label: '正常' },
            ]}
            onChange={(e) => {}}
          />
          <Input
            style={{
              width: 250,
              background: 'rgba(50, 111, 167, 0.3)',
              borderRadius: 20,
              border: 'rgb(50, 111, 167)',
              marginLeft: 20,
            }}
            onChange={InputChange}
            placeholder="请输入名称搜索"
            suffix={<SearchOutlined />}
          ></Input>
        </div>
        <CommonTable
          dataSource={dataSource}
          columns={columns}
          scroll={{ x: 700, y: 550 }}
          pagination={{
            total: dataSource?.length,
            pageSize: searchData?.count,
            showQuickJumper: false,
            showSizeChanger: false,
            onChange: (page, pageSize) => {
              setSearchData({
                ...searchData,
                page: page,
                count: pageSize,
              });
            },
            //  hideOnSinglePage: true,
          }}
        />
        {/* <EventPicList
          listData={listData}
          listHeight={700}
          setParams={(data) => {
            setFetchParams({ ...fetchParams, page: data.current.page });
          }}
          handleDetail={(details) => {
            setDetailModalOpt({
              open: true,
              eventId: details?.asriskId,
              ...details,
            });
          }}
        /> */}
      </div>
      {/* 事件详情 */}
      <Modal
        open={detailModalOpt?.open}
        titleRender={titleRender}
        onCancel={() => {
          setDetailModalOpt({
            open: false,
            title: '事件详情',
            eventId: '',
          });
        }}
        width={2650}
        height={900}
      >
        {detailModalOpt?.open && (
          <BaseInfo
            eventId={detailModalOpt?.eventId}
            detail={detailModalOpt}
            onChangeOpt={(val) => {
              console.log(val);

              setDetailModalOpt({
                ...detailModalOpt,
                position: val?.position,
                eventType: val?.event_type,
                riskLevelName: val?.risklevel,
              });
            }}
          />
        )}
      </Modal>
    </Flex>
  );
};

export default IndustrySign;
